import { scaleOrdinal } from 'd3';

const colorScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range(['#c11d1d', '#eae600']);

const radiusScale = scaleOrdinal()
	.domain(['apple', 'lemon'])
	.range([80, 50]);

export const fruitBowl = (selection, props) => {
  const {fruits, height} = props;
  
  const bowl = selection.selectAll('rect')
  	.data([null]).enter()
  	.append('rect')
  	.attr('width', 920)
  	.attr('height', 300)
  	.attr('y', 100)
  .attr('rx', 150);
  
  const groups = selection.selectAll('g')
  	.data(fruits);
  const groupsEnter =  groups.enter().append('g');
  groupsEnter
  .merge(groups)
    .attr('transform', (d, i) => 
         `translate(${100 + i * 180}, ${height / 2})`);
   groups.exit().remove();
  
	const circles = groups.select('circle');
	groupsEnter.append('circle')
    .merge(circles)
      .attr('fill', d => colorScale(d.type))
      .attr('r',  d => radiusScale(d.type));

  const text = groups.select('text');
  groupsEnter.append('text')
  .merge(text)
    .text(d => d.type)
  	.attr('y', 120);
   text
    .exit().remove();
}